PinwheelBillPayloadBuilder class

Implemented types

Properties

amountCents int?
covariantgetter/setter pair
frequency String?
covariantgetter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nextPaymentDate String?
covariantgetter/setter pair
platformId String?
covariantgetter/setter pair
platformName String?
covariantgetter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() PinwheelBillPayload
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(covariant PinwheelBillPayload other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(PinwheelBillPayloadBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited