PinwheelBillSwitchPlatformsPayload class abstract

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
platforms → BuiltList<PinwheelBillSwitchPlatform>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PinwheelBillSwitchPlatformsPayloadBuilder)) PinwheelBillSwitchPlatformsPayload
Rebuilds the instance.
inherited
toBuilder() PinwheelBillSwitchPlatformsPayloadBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PinwheelBillSwitchPlatformsPayload>
no setter