PinwheelTarget class abstract

Implemented types

Constructors

PinwheelTarget([dynamic updates(PinwheelTargetBuilder b)])
factory

Properties

accountName String?
no setter
accountType String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PinwheelTargetBuilder)) PinwheelTarget
Rebuilds the instance.
inherited
toBuilder() PinwheelTargetBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PinwheelTarget>
no setter