PinwheelBillSwitchPayload class abstract
- Implemented types
Constructors
- PinwheelBillSwitchPayload([void updates(PinwheelBillSwitchPayloadBuilder)])
-
factory
Properties
- accountId → String?
-
no setter
- amountCents → int
-
no setter
- frequency → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isIntegratedSwitch → bool
-
no setter
- nextPaymentDate → String
-
no setter
- platformId → String
-
no setter
- platformName → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(PinwheelBillSwitchPayloadBuilder)) → PinwheelBillSwitchPayload -
Rebuilds the instance.
inherited
-
toBuilder(
) → PinwheelBillSwitchPayloadBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
PinwheelBillSwitchPayload> -
no setter