PinwheelUserActivatedPayload class abstract

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
solutionName String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(PinwheelUserActivatedPayloadBuilder)) PinwheelUserActivatedPayload
Rebuilds the instance.
inherited
toBuilder() PinwheelUserActivatedPayloadBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<PinwheelUserActivatedPayload>
no setter